lilypondfiletools.LilyPondFile
==============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.lilypond_format

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.default_paper_size

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.file_initial_system_comments

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.file_initial_system_includes

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.file_initial_user_comments

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.file_initial_user_includes

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.global_staff_size

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.append

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.count

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.extend

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.index

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.insert

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.pop

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.remove

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.reverse

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.sort

    Inherited from :py:class:`__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__add__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__contains__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__delitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__delslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__eq__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__ge__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__getitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__getslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__gt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__iadd__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__imul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__iter__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__le__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__len__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__lt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__mul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__ne__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__repr__

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__reversed__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__rmul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__setitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.LilyPondFile.__setslice__

    Inherited from :py:class:`__builtin__.list`
